<?php

/**
 * A column to indicate the state of a model's property
 *
 * @author K. O. Frimpong
 */
Yii::import('zii.widgets.grid.CGridColumn');

class StateGridColumn extends CGridColumn {


    /**
     * @var array the HTML options for the image tag.
     */
    public $imageOptions = array();
    /**
     * @var string the url of image to use for 'on' state
     */
    public $onImageUrl;
	 /**
     * @var string the url of image to use for 'off' state
     */
	public $offImageUrl;
	
    /**
     * @var string the attribute name of the data model. The corresponding attribute value will be rendered
     * in each data cell. If {@link value} is specified, this property will be ignored
     * unless the column needs to be sortable or filtered.
     * @see value
     * @see sortable
     */
    public $name;
    /**
     * @var string a PHP expression that will be evaluated for every data cell and whose result will be rendered
     * as the content of the data cells. In this expression, the variable
     * <code>$row</code> the row number (zero-based); <code>$data</code> the data model for the row;
     * and <code>$this</code> the column object.
     */
    public $value;
    /**
     * @var boolean whether the column is sortable. If so, the header cell will contain a link that may trigger the sorting.
     * Defaults to true. Note that if {@link name} is not set, or if {@link name} is not allowed by {@link CSort},
     * this property will be treated as false.
     * @see name
     */
    public $sortable = true;
    /**
     * @var mixed the HTML code representing a filter input (eg a text field, a dropdown list)
     * that is used for this data column. This property is effective only when
     * {@link CGridView::enableFiltering} is set true.
     * If this property is not set, a text field will be generated as the filter input;
     * If this property is an array, a dropdown list will be generated that uses this property value as
     * the list options.
     * If you don't want a filter for this data column, set this value to false.
     * @since 1.1.1
     */
    public $filter;

    
    /**
     * Renders the data cell content.
     * @param integer the row number (zero-based)
     * @param mixed the data associated with the row
     */
    protected function renderDataCellContent($row, $data) {
        if ($this->value !== null) {
            $value = $this->evaluateExpression($this->value, array('data' => $data, 'row' => $row));
        }
        else {
            $value = CHtml::resolveValue($data, $this->name);
        } 
        if ($value) {
            if ($this->onImageUrl) {
                $this->imageOptions['src'] = $this->onImageUrl;
            }
            else {
                $basedir = dirname(__FILE__) . '/widgetfiles';
                $baseUrl = Yii::app()->assetManager->publish($basedir);
                $this->imageOptions['src'] = $baseUrl . '/images/checked.png';
            }           
        }
		else{
			if ($this->offImageUrl) {
                $this->imageOptions['src'] = $this->offImageUrl;
            }
            else {
                $basedir = dirname(__FILE__) . '/widgetfiles';
                $baseUrl = Yii::app()->assetManager->publish($basedir);
                $this->imageOptions['src'] = $baseUrl . '/images/cancel.png';
            } 
		}
		echo CHtml::tag('img', $this->imageOptions);
    }

    /**
     * Renders the filter cell content.
     * This method will render the {@link filter} as is if it is a string.
     * If {@link filter} is an array, it is assumed to be a list of options, and a dropdown selector will be rendered.
     * Otherwise if {@link filter} is not false, a text field is rendered.
     * @since 1.1.1
     */
    protected function renderFilterCellContent() {
        if (is_string($this->filter)){
            echo $this->filter;
        }
        else if ($this->filter !== false && $this->grid->filter !== null && $this->name !== null && strpos($this->name, '.') === false) {
            if (is_array($this->filter))
                echo CHtml::activeDropDownList($this->grid->filter, $this->name, $this->filter, array('id' => false, 'prompt' => ''));
        }
        else
            parent::renderFilterCellContent();
    }

    /**
     * Renders the header cell content.
     * This method will render a link that can trigger the sorting if the column is sortable.
     */
    protected function renderHeaderCellContent() {
        if ($this->grid->enableSorting && $this->sortable && $this->name !== null)
            echo $this->grid->dataProvider->getSort()->link($this->name, $this->header);
        else if ($this->name !== null && $this->header === null) {
            if ($this->grid->dataProvider instanceof CActiveDataProvider)
                echo CHtml::encode($this->grid->dataProvider->model->getAttributeLabel($this->name));
            else
                echo CHtml::encode(ucfirst($this->name));
        }
        else
            parent::renderHeaderCellContent();
    }

}

